==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/DNSSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class DNSSpecFluentImpl<A extends io.fabric8.openshift.api.model.DNSSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.DNSSpecFluent<A>{
  public DNSSpecFluentImpl() {
  }
  public DNSSpecFluentImpl(io.fabric8.openshift.api.model.DNSSpec instance) {
    this.withBaseDomain(instance.getBaseDomain()); 
    this.withPrivateZone(instance.getPrivateZone()); 
    this.withPublicZone(instance.getPublicZone()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String baseDomain;
  private io.fabric8.openshift.api.model.DNSZoneBuilder privateZone;
  private io.fabric8.openshift.api.model.DNSZoneBuilder publicZone;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getBaseDomain() {
    return this.baseDomain;
  }
  public A withBaseDomain(java.lang.String baseDomain) {
    this.baseDomain=baseDomain; return (A) this;
  }
  public java.lang.Boolean hasBaseDomain() {
    return this.baseDomain != null;
  }
  
  /**
   * Method is deprecated. use withBaseDomain instead.
   */
  @java.lang.Deprecated
  public A withNewBaseDomain(java.lang.String arg0) {
    return (A)withBaseDomain(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildPrivateZone instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.DNSZone getPrivateZone() {
    return this.privateZone!=null?this.privateZone.build():null;
  }
  public io.fabric8.openshift.api.model.DNSZone buildPrivateZone() {
    return this.privateZone!=null?this.privateZone.build():null;
  }
  public A withPrivateZone(io.fabric8.openshift.api.model.DNSZone privateZone) {
    _visitables.get("privateZone").remove(this.privateZone);
    if (privateZone!=null){ this.privateZone= new io.fabric8.openshift.api.model.DNSZoneBuilder(privateZone); _visitables.get("privateZone").add(this.privateZone);} return (A) this;
  }
  public java.lang.Boolean hasPrivateZone() {
    return this.privateZone != null;
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PrivateZoneNested<A> withNewPrivateZone() {
    return new io.fabric8.openshift.api.model.DNSSpecFluentImpl.PrivateZoneNestedImpl();
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PrivateZoneNested<A> withNewPrivateZoneLike(io.fabric8.openshift.api.model.DNSZone item) {
    return new io.fabric8.openshift.api.model.DNSSpecFluentImpl.PrivateZoneNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PrivateZoneNested<A> editPrivateZone() {
    return withNewPrivateZoneLike(getPrivateZone());
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PrivateZoneNested<A> editOrNewPrivateZone() {
    return withNewPrivateZoneLike(getPrivateZone() != null ? getPrivateZone(): new io.fabric8.openshift.api.model.DNSZoneBuilder().build());
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PrivateZoneNested<A> editOrNewPrivateZoneLike(io.fabric8.openshift.api.model.DNSZone item) {
    return withNewPrivateZoneLike(getPrivateZone() != null ? getPrivateZone(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPublicZone instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.DNSZone getPublicZone() {
    return this.publicZone!=null?this.publicZone.build():null;
  }
  public io.fabric8.openshift.api.model.DNSZone buildPublicZone() {
    return this.publicZone!=null?this.publicZone.build():null;
  }
  public A withPublicZone(io.fabric8.openshift.api.model.DNSZone publicZone) {
    _visitables.get("publicZone").remove(this.publicZone);
    if (publicZone!=null){ this.publicZone= new io.fabric8.openshift.api.model.DNSZoneBuilder(publicZone); _visitables.get("publicZone").add(this.publicZone);} return (A) this;
  }
  public java.lang.Boolean hasPublicZone() {
    return this.publicZone != null;
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PublicZoneNested<A> withNewPublicZone() {
    return new io.fabric8.openshift.api.model.DNSSpecFluentImpl.PublicZoneNestedImpl();
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PublicZoneNested<A> withNewPublicZoneLike(io.fabric8.openshift.api.model.DNSZone item) {
    return new io.fabric8.openshift.api.model.DNSSpecFluentImpl.PublicZoneNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PublicZoneNested<A> editPublicZone() {
    return withNewPublicZoneLike(getPublicZone());
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PublicZoneNested<A> editOrNewPublicZone() {
    return withNewPublicZoneLike(getPublicZone() != null ? getPublicZone(): new io.fabric8.openshift.api.model.DNSZoneBuilder().build());
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PublicZoneNested<A> editOrNewPublicZoneLike(io.fabric8.openshift.api.model.DNSZone item) {
    return withNewPublicZoneLike(getPublicZone() != null ? getPublicZone(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DNSSpecFluentImpl that = (DNSSpecFluentImpl) o;
    if (baseDomain != null ? !baseDomain.equals(that.baseDomain) :that.baseDomain != null) return false;
    if (privateZone != null ? !privateZone.equals(that.privateZone) :that.privateZone != null) return false;
    if (publicZone != null ? !publicZone.equals(that.publicZone) :that.publicZone != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(baseDomain,  privateZone,  publicZone,  additionalProperties,  super.hashCode());
  }
  public class PrivateZoneNestedImpl<N> extends io.fabric8.openshift.api.model.DNSZoneFluentImpl<io.fabric8.openshift.api.model.DNSSpecFluent.PrivateZoneNested<N>> implements io.fabric8.openshift.api.model.DNSSpecFluent.PrivateZoneNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PrivateZoneNestedImpl(io.fabric8.openshift.api.model.DNSZone item) {
      this.builder = new io.fabric8.openshift.api.model.DNSZoneBuilder(this, item);
    }
    PrivateZoneNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.DNSZoneBuilder(this);
    }
    io.fabric8.openshift.api.model.DNSZoneBuilder builder;
    public N and() {
      return (N) DNSSpecFluentImpl.this.withPrivateZone(builder.build());
    }
    public N endPrivateZone() {
      return and();
    }
    
  }
  public class PublicZoneNestedImpl<N> extends io.fabric8.openshift.api.model.DNSZoneFluentImpl<io.fabric8.openshift.api.model.DNSSpecFluent.PublicZoneNested<N>> implements io.fabric8.openshift.api.model.DNSSpecFluent.PublicZoneNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PublicZoneNestedImpl(io.fabric8.openshift.api.model.DNSZone item) {
      this.builder = new io.fabric8.openshift.api.model.DNSZoneBuilder(this, item);
    }
    PublicZoneNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.DNSZoneBuilder(this);
    }
    io.fabric8.openshift.api.model.DNSZoneBuilder builder;
    public N and() {
      return (N) DNSSpecFluentImpl.this.withPublicZone(builder.build());
    }
    public N endPublicZone() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/DNSSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class DNSSpecFluentImpl<A extends io.fabric8.openshift.api.model.DNSSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.DNSSpecFluent<A>{
  public DNSSpecFluentImpl() {
  }
  public DNSSpecFluentImpl(io.fabric8.openshift.api.model.DNSSpec instance) {
    this.withBaseDomain(instance.getBaseDomain()); 
    this.withPrivateZone(instance.getPrivateZone()); 
    this.withPublicZone(instance.getPublicZone()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String baseDomain;
  private io.fabric8.openshift.api.model.DNSZoneBuilder privateZone;
  private io.fabric8.openshift.api.model.DNSZoneBuilder publicZone;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getBaseDomain() {
    return this.baseDomain;
  }
  public A withBaseDomain(java.lang.String baseDomain) {
    this.baseDomain=baseDomain; return (A) this;
  }
  public java.lang.Boolean hasBaseDomain() {
    return this.baseDomain != null;
  }
  
  /**
   * Method is deprecated. use withBaseDomain instead.
   */
  @java.lang.Deprecated
  public A withNewBaseDomain(java.lang.String arg0) {
    return (A)withBaseDomain(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildPrivateZone instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.DNSZone getPrivateZone() {
    return this.privateZone!=null?this.privateZone.build():null;
  }
  public io.fabric8.openshift.api.model.DNSZone buildPrivateZone() {
    return this.privateZone!=null?this.privateZone.build():null;
  }
  public A withPrivateZone(io.fabric8.openshift.api.model.DNSZone privateZone) {
    _visitables.get("privateZone").remove(this.privateZone);
    if (privateZone!=null){ this.privateZone= new io.fabric8.openshift.api.model.DNSZoneBuilder(privateZone); _visitables.get("privateZone").add(this.privateZone);} return (A) this;
  }
  public java.lang.Boolean hasPrivateZone() {
    return this.privateZone != null;
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PrivateZoneNested<A> withNewPrivateZone() {
    return new io.fabric8.openshift.api.model.DNSSpecFluentImpl.PrivateZoneNestedImpl();
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PrivateZoneNested<A> withNewPrivateZoneLike(io.fabric8.openshift.api.model.DNSZone item) {
    return new io.fabric8.openshift.api.model.DNSSpecFluentImpl.PrivateZoneNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PrivateZoneNested<A> editPrivateZone() {
    return withNewPrivateZoneLike(getPrivateZone());
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PrivateZoneNested<A> editOrNewPrivateZone() {
    return withNewPrivateZoneLike(getPrivateZone() != null ? getPrivateZone(): new io.fabric8.openshift.api.model.DNSZoneBuilder().build());
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PrivateZoneNested<A> editOrNewPrivateZoneLike(io.fabric8.openshift.api.model.DNSZone item) {
    return withNewPrivateZoneLike(getPrivateZone() != null ? getPrivateZone(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPublicZone instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.DNSZone getPublicZone() {
    return this.publicZone!=null?this.publicZone.build():null;
  }
  public io.fabric8.openshift.api.model.DNSZone buildPublicZone() {
    return this.publicZone!=null?this.publicZone.build():null;
  }
  public A withPublicZone(io.fabric8.openshift.api.model.DNSZone publicZone) {
    _visitables.get("publicZone").remove(this.publicZone);
    if (publicZone!=null){ this.publicZone= new io.fabric8.openshift.api.model.DNSZoneBuilder(publicZone); _visitables.get("publicZone").add(this.publicZone);} return (A) this;
  }
  public java.lang.Boolean hasPublicZone() {
    return this.publicZone != null;
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PublicZoneNested<A> withNewPublicZone() {
    return new io.fabric8.openshift.api.model.DNSSpecFluentImpl.PublicZoneNestedImpl();
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PublicZoneNested<A> withNewPublicZoneLike(io.fabric8.openshift.api.model.DNSZone item) {
    return new io.fabric8.openshift.api.model.DNSSpecFluentImpl.PublicZoneNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PublicZoneNested<A> editPublicZone() {
    return withNewPublicZoneLike(getPublicZone());
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PublicZoneNested<A> editOrNewPublicZone() {
    return withNewPublicZoneLike(getPublicZone() != null ? getPublicZone(): new io.fabric8.openshift.api.model.DNSZoneBuilder().build());
  }
  public io.fabric8.openshift.api.model.DNSSpecFluent.PublicZoneNested<A> editOrNewPublicZoneLike(io.fabric8.openshift.api.model.DNSZone item) {
    return withNewPublicZoneLike(getPublicZone() != null ? getPublicZone(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DNSSpecFluentImpl that = (DNSSpecFluentImpl) o;
    if (baseDomain != null ? !baseDomain.equals(that.baseDomain) :that.baseDomain != null) return false;
    if (privateZone != null ? !privateZone.equals(that.privateZone) :that.privateZone != null) return false;
    if (publicZone != null ? !publicZone.equals(that.publicZone) :that.publicZone != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(baseDomain,  privateZone,  publicZone,  additionalProperties,  super.hashCode());
  }
  public class PrivateZoneNestedImpl<N> extends io.fabric8.openshift.api.model.DNSZoneFluentImpl<io.fabric8.openshift.api.model.DNSSpecFluent.PrivateZoneNested<N>> implements io.fabric8.openshift.api.model.DNSSpecFluent.PrivateZoneNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PrivateZoneNestedImpl(io.fabric8.openshift.api.model.DNSZone item) {
      this.builder = new io.fabric8.openshift.api.model.DNSZoneBuilder(this, item);
    }
    PrivateZoneNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.DNSZoneBuilder(this);
    }
    io.fabric8.openshift.api.model.DNSZoneBuilder builder;
    public N and() {
      return (N) DNSSpecFluentImpl.this.withPrivateZone(builder.build());
    }
    public N endPrivateZone() {
      return and();
    }
    
  }
  public class PublicZoneNestedImpl<N> extends io.fabric8.openshift.api.model.DNSZoneFluentImpl<io.fabric8.openshift.api.model.DNSSpecFluent.PublicZoneNested<N>> implements io.fabric8.openshift.api.model.DNSSpecFluent.PublicZoneNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PublicZoneNestedImpl(io.fabric8.openshift.api.model.DNSZone item) {
      this.builder = new io.fabric8.openshift.api.model.DNSZoneBuilder(this, item);
    }
    PublicZoneNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.DNSZoneBuilder(this);
    }
    io.fabric8.openshift.api.model.DNSZoneBuilder builder;
    public N and() {
      return (N) DNSSpecFluentImpl.this.withPublicZone(builder.build());
    }
    public N endPublicZone() {
      return and();
    }
    
  }
  
}
